@@ -702,7 +702,7 @@ sub keybinder {
             return;
         }
         if ($key eq "s") {
-            &statusline("save data and continue editing");
+            &statusline("Save data and continue editing");
             $breakout = 1;
             return;
         }
@@ -754,7 +754,7 @@ sub keybinder {
         $matrixwidget->{"VC.$vc.$vr"}->{-canvasscr}->attroff(A_STANDOUT);
         $matrixwidget->{"VC.$vc.$vr"}->draw;
         $widget->{"dummy"}->focus;
-        &statusline("save data and continue editing");
+        &statusline("Save data and continue editing");
         $breakout = 1;
         return;
     }
@@ -1417,11 +1417,11 @@ sub statusline() {
     my $wstat = $widget->{'stat'}->width;
     if (not defined $textl or $textl eq "") {
         $textl = "";
-        $textl .= "[+] " if ($matrixdata->{"dirty"});
-        $textl .= "ESC=Menu; F1=Help";
+        $textl .= "Accounting System (AS), " . $matrixdata->{"progname"} . " " . $matrixdata->{"progvers"} . "";
+        $textl .= " [+]" if ($matrixdata->{"dirty"});
     }
     if (not defined $textr or $textr eq "") {
-        $textr = "Accounting System (" . $matrixdata->{"progname"} . " " . $matrixdata->{"progvers"} . ")";
+        $textr .= "RET:Enter/Leave s:Save q:Quit ESC:Menu F1:Help";
     }
     my $textf = " " x ($wstat -2 -length($textl) -1 -1 -length($textr) - 2);
     my $text  = sprintf("  %s %s %s  ", $textl, $textf, $textr);
